@@ -18,12 +18,17 @@ spec = do
   describe "Data Version instance" $
     it "allows obtaining a Version constructor" $
       dataTypeName (dataTypeOf (Version [1,2,3] [])) `shouldBe`
--- Some old versions of GHC incorrectly return "Version" instead of
--- "Data.Version.Version" due to
--- https://gitlab.haskell.org/ghc/ghc/-/issues/20371.
 #if __GLASGOW_HASKELL__ >= 801 && __GLASGOW_HASKELL__ < 903
+        -- Some old versions of GHC incorrectly return "Version" due to
+        -- https://gitlab.haskell.org/ghc/ghc/-/issues/20371.
         "Version"
+#elif __GLASGOW_HASKELL__ >= 910
+        -- In GHC 9.10 and later, Version is defined in
+        -- GHC.Internal.Data.Version (in the ghc-internal library).
+        "GHC.Internal.Data.Version.Version"
 #else
+        -- In older versions of GHC, Version is defined in Data.Version (in the
+        -- base library).
         "Data.Version.Version"
 #endif
 
